# Changelog

## 1.0.0 (2024-09-16)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/lumalabs/lumaai-python/compare/v0.1.0-alpha.1...v1.0.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#27](https://github.com/lumalabs/lumaai-python/issues/27)) ([23fe5ec](https://github.com/lumalabs/lumaai-python/commit/23fe5ecb07c1c7f6305b14f139220af293c8c980))


### Chores

* **internal:** bump pyright / mypy version ([#24](https://github.com/lumalabs/lumaai-python/issues/24)) ([be1f767](https://github.com/lumalabs/lumaai-python/commit/be1f767627075f4dd7b8a0356970c115287e751d))
* update SDK settings ([#26](https://github.com/lumalabs/lumaai-python/issues/26)) ([051824c](https://github.com/lumalabs/lumaai-python/commit/051824ca02ad4adcadcac6eb96cb30eb6dea4dbf))

## 0.1.0-alpha.1 (2024-09-16)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/lumalabs/lumaai-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** OpenAPI spec update via Stainless API ([#11](https://github.com/lumalabs/lumaai-python/issues/11)) ([377f179](https://github.com/lumalabs/lumaai-python/commit/377f179cd6199a5decf80c2a846a84ef261a8925))
* **api:** OpenAPI spec update via Stainless API ([#13](https://github.com/lumalabs/lumaai-python/issues/13)) ([cce8ca4](https://github.com/lumalabs/lumaai-python/commit/cce8ca4fa4c1b3bb529f4d98c5ec68606c5b43f6))
* **api:** OpenAPI spec update via Stainless API ([#14](https://github.com/lumalabs/lumaai-python/issues/14)) ([4917a77](https://github.com/lumalabs/lumaai-python/commit/4917a777b96afca5f01c07444dfd7f68cfcc9911))
* **api:** OpenAPI spec update via Stainless API ([#15](https://github.com/lumalabs/lumaai-python/issues/15)) ([0c49e40](https://github.com/lumalabs/lumaai-python/commit/0c49e406df3aca45f18883cc1413c3c9dc392ee6))
* **api:** OpenAPI spec update via Stainless API ([#16](https://github.com/lumalabs/lumaai-python/issues/16)) ([8c02223](https://github.com/lumalabs/lumaai-python/commit/8c02223c49db15d4132184c6d4248f1d466561b9))
* **api:** OpenAPI spec update via Stainless API ([#17](https://github.com/lumalabs/lumaai-python/issues/17)) ([8598e38](https://github.com/lumalabs/lumaai-python/commit/8598e3851effef0025d7f934772826ba0186b290))
* **api:** OpenAPI spec update via Stainless API ([#18](https://github.com/lumalabs/lumaai-python/issues/18)) ([cd810fd](https://github.com/lumalabs/lumaai-python/commit/cd810fd3633e0df252b22152f0b58121275cab13))
* **api:** OpenAPI spec update via Stainless API ([#20](https://github.com/lumalabs/lumaai-python/issues/20)) ([9762701](https://github.com/lumalabs/lumaai-python/commit/97627012cc3c4862a0ce3d76e7db8ef6c8d6b954))
* **api:** update via SDK Studio ([#9](https://github.com/lumalabs/lumaai-python/issues/9)) ([83f37c3](https://github.com/lumalabs/lumaai-python/commit/83f37c37c12826c4c850e2f06b21022690b59fb9))


### Chores

* **internal:** bump ruff ([#21](https://github.com/lumalabs/lumaai-python/issues/21)) ([b4caca2](https://github.com/lumalabs/lumaai-python/commit/b4caca23ad06baf9c3047c0d71fd898d33718a0a))
* **internal:** codegen related update ([#12](https://github.com/lumalabs/lumaai-python/issues/12)) ([79ab180](https://github.com/lumalabs/lumaai-python/commit/79ab1809977f8df46874f9942161585e7849f97c))


### Documentation

* update CONTRIBUTING.md ([#19](https://github.com/lumalabs/lumaai-python/issues/19)) ([4783573](https://github.com/lumalabs/lumaai-python/commit/4783573b6b91b969720b54f8b6999f04b4e52478))
